
"""Evolution programming in python with talib and gplearn inspired API
``tagenalgo`` is a parameter optimization algorithm for trading strategy.
"""

from __future__ import absolute_import
from .hello import *

__version__ = '1.0.1'
__license__ = 'BSD'